// 封装 fetch 请求的函数
async function fetchData(url, options = {}) {
    const defaultOptions = {
        method: 'GET',
        headers: {
            'Content-Type': 'application/json',
        },
    };
    // 合并用户自定义的选项
    const finalOptions = {...defaultOptions, ...options};
    const response = await fetch(url, finalOptions);
    if (!response.ok) {
        throw new Error(`HTTP error! status: ${response.status}`);
    }
    return await response.json(); // 返回 JSON 格式的响应
}

// 处理来自其他部分的消息
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    const {type, url, options} = request;
    switch (type) {
        case 'fetchData':
            fetchData(url, options)
                .then(response => sendResponse({success: true, data: response}))
                .catch(error => sendResponse({success: false, error: error.message}));
            break;
        default:
            sendResponse({success: false, error: 'Unknown request type'});
            break;
    }
    // 返回 true，以表示将异步发送响应
    return true;
});

